==> codegrade-15.2.0-py3-none-any.whl: codegrade/models/feedback_threads_initially_collapsed_setting.py <==
"""The module that defines the ``FeedbackThreadsInitiallyCollapsedSetting`` model.

SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
"""

import typing as t
from dataclasses import dataclass, field

import cg_request_args as rqa

from ..utils import to_dict


@dataclass
class FeedbackThreadsInitiallyCollapsedSetting:
    """ """

    name: "t.Literal['FEEDBACK_THREADS_INITIALLY_COLLAPSED']"
    value: "t.Optional[int]"

    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)

    data_parser: t.ClassVar = rqa.Lazy(
        lambda: rqa.FixedMapping(
            rqa.RequiredArgument(
                "name",
                rqa.StringEnum("FEEDBACK_THREADS_INITIALLY_COLLAPSED"),
                doc="",
            ),
            rqa.RequiredArgument(
                "value",
                rqa.Nullable(rqa.SimpleValue.int),
                doc="",
            ),
        ).use_readable_describe(True)
    )

    def to_dict(self) -> t.Dict[str, t.Any]:
        res: t.Dict[str, t.Any] = {
            "name": to_dict(self.name),
            "value": to_dict(self.value),
        }
        return res

    @classmethod
    def from_dict(
        cls: t.Type["FeedbackThreadsInitiallyCollapsedSetting"],
        d: t.Dict[str, t.Any],
    ) -> "FeedbackThreadsInitiallyCollapsedSetting":
        parsed = cls.data_parser.try_parse(d)

        res = cls(
            name=parsed.name,
            value=parsed.value,
        )
        res.raw_data = d
        return res

==> codegrade-17.0.1-py3-none-any.whl: codegrade/models/feedback_threads_initially_collapsed_setting.py <==
"""The module that defines the ``FeedbackThreadsInitiallyCollapsedSetting`` model.

SPDX-License-Identifier: AGPL-3.0-only OR BSD-3-Clause-Clear
"""

from __future__ import annotations

import typing as t
from dataclasses import dataclass, field

import cg_request_args as rqa

from ..utils import to_dict


@dataclass
class FeedbackThreadsInitiallyCollapsedSetting:
    """ """

    name: t.Literal["FEEDBACK_THREADS_INITIALLY_COLLAPSED"]
    value: t.Optional[int]

    raw_data: t.Optional[t.Dict[str, t.Any]] = field(init=False, repr=False)

    data_parser: t.ClassVar = rqa.Lazy(
        lambda: rqa.FixedMapping(
            rqa.RequiredArgument(
                "name",
                rqa.StringEnum("FEEDBACK_THREADS_INITIALLY_COLLAPSED"),
                doc="",
            ),
            rqa.RequiredArgument(
                "value",
                rqa.Nullable(rqa.SimpleValue.int),
                doc="",
            ),
        ).use_readable_describe(True)
    )

    def to_dict(self) -> t.Dict[str, t.Any]:
        res: t.Dict[str, t.Any] = {
            "name": to_dict(self.name),
            "value": to_dict(self.value),
        }
        return res

    @classmethod
    def from_dict(
        cls: t.Type[FeedbackThreadsInitiallyCollapsedSetting],
        d: t.Dict[str, t.Any],
    ) -> FeedbackThreadsInitiallyCollapsedSetting:
        parsed = cls.data_parser.try_parse(d)

        res = cls(
            name=parsed.name,
            value=parsed.value,
        )
        res.raw_data = d
        return res
